Overview
========

Graphical user interface (GUI) libraries are usually designed to address issues 
that are far more complex than a simple dialog box. As a consequence, generating 
simple GUI like form layouts or dialogs is generally not as easy as it should be: 
the feature-line count ratio is very low for the most simple dialog boxes. 
That's where ``formlayout`` can be useful, by providing a simplistic API (a 
single function ``fedit`` taking lists as parameters) for creating simple form 
layouts.

*to be continued...*
